diff libmlk-core/mlk/core/panic.c @ 475:1a1265445157

core: forgot panic_handler
author David Demelier <markand@malikania.fr>
date Mon, 27 Feb 2023 12:44:13 +0100
parents 01f5580e43d1
children d6757c30658e
line wrap: on
line diff
--- a/libmlk-core/mlk/core/panic.c	Mon Feb 27 12:41:53 2023 +0100
+++ b/libmlk-core/mlk/core/panic.c	Mon Feb 27 12:44:13 2023 +0100
@@ -31,7 +31,7 @@
 	exit(1);
 }
 
-void (*panic_handler)(void) = terminate;
+void (*mlk_panic_handler)(void) = terminate;
 
 void
 mlk_panicf(const char *fmt, ...)
@@ -55,7 +55,7 @@
 mlk_panicva(const char *fmt, va_list ap)
 {
 	assert(fmt);
-	assert(panic_handler);
+	assert(mlk_panic_handler);
 
 	errorva(fmt, ap);
 	mlk_panic();
@@ -64,13 +64,13 @@
 void
 mlk_panic(void)
 {
-	assert(panic_handler);
+	assert(mlk_panic_handler);
 
-	panic_handler();
+	mlk_panic_handler();
 
 	/*
 	 * This should not happen, if it does it means the user did not fully
 	 * satisfied the constraint of panic_handler.
 	 */
 	fprintf(stderr, "abort: panic handler returned\n");
 	exit(1);
@@ -64,13 +64,13 @@
 	/*
 	 * This should not happen, if it does it means the user did not fully
-	 * satisfied the constraint of panic_handler.
+	 * satisfied the constraint of mlk_panic_handler.
 	 */
 	fprintf(stderr, "abort: panic handler returned\n");